pub fn set_terminal_width_detector(detector: fn() -> Option<usize>)Expand description
Overrides the detector used to query terminal width.
Accepts a fn pointer or a non-capturing closure. The detector returns
Some(cols) when a width can be determined and None when output is not
a terminal. Useful to force a fixed width in snapshot tests.